package com.example.elbuenopeso.database

import android.content.ContentValues
import android.content.Context
import android.database.Cursor
import android.database.SQLException
import android.database.sqlite.SQLiteDatabase
import android.util.Log
import com.example.elbuenopeso.models.AdModel


class DBManager //init(); // Useful for adding ads for the first time.
private constructor(private val context: Context) {
    private var dbHelper: DBHelper? = null
    private var database: SQLiteDatabase? = null
    @Throws(SQLException::class)
    fun open(): DBManager {
        this.dbHelper = DBHelper(this.context)
        this.database = this.dbHelper!!.writableDatabase
        return this
    }

    fun close() {
        this.dbHelper?.close()
    }

    // Add ads manually.

    fun init() {
        this.open()
        this.insert(
            AdModel("Poutre", "1 rue Jean-Pierre", "drawable/pichu.png", 25.0)
        )
        this.insert(
            AdModel("Briques", "2 rue Jean-Michel", "drawable/pichu.png", 16.0)
        )
        this.insert(
            AdModel("Maison de pierre", "7 rue Joris Belhomme", "drawable/pichu.png", 3.99)
        )
        this.insert(
            AdModel("Mur en bois", "4 rue Alain-Juju", "drawable/pichu.png", 7.2)
        )
        this.insert(
            AdModel("Téléphone de Timothé", "8 rue de Timothé", "drawable/pichu.png", 0.85)
        )
        this.insert(
            AdModel("Oridnateur", "10 rue Jean-Charles", "drawable/pichu.png", 104.98)
        )
        this.insert(
            AdModel("Charnières", "22 rue Jeanne-Marie", "drawable/pichu.png", 2648.97)
        )
        this.insert(
            AdModel("Porte en marbre", "1 rue Jean-Pierre", "drawable/pichu.png", 480.0)
        )
        this.insert(
            AdModel("Cheminée", "33 rue du Gouvernement", "drawable/pichu.png", 800.0)
        )
    }

    fun insert(ad: AdModel) {
        val contentValue = ContentValues()
        contentValue.put(DBHelper.TITLE, ad.title)
        contentValue.put(DBHelper.ADDRESS, ad.address)
        contentValue.put(DBHelper.IMAGE, ad.image)
        contentValue.put(DBHelper.PRIX, ad.prix)
        this.database!!.insert(DBHelper.TABLE_NAME, null, contentValue)
    }

    fun fetch(): Cursor? {
        val columns: Array<String> =
            arrayOf(DBHelper._ID, DBHelper.TITLE, DBHelper.ADDRESS, DBHelper.IMAGE, DBHelper.PRIX)
        columns.forEach { e -> Log.i(null, e) }
        val cursor = this.database!!.query(DBHelper.TABLE_NAME, columns, null, null, null, null, null)
        cursor?.moveToFirst()
        return cursor
    }

    fun update(_id: Long, ad: AdModel): Int {
        val contentValues = ContentValues()
        contentValues.put(DBHelper.TITLE, ad.title)
        contentValues.put(DBHelper.ADDRESS, ad.address)
        contentValues.put(DBHelper.IMAGE, ad.image)
        return this.database!!.update(
            DBHelper.TABLE_NAME,
            contentValues,
            DBHelper._ID + " = " + _id,
            null
        )
    }

    fun delete(_id: Long) {
        this.database!!.delete(DBHelper.TABLE_NAME, DBHelper._ID + "=" + _id, null)
    }

    fun getById(id: Int): AdModel? {
        return this.dbHelper?.getById(id)
    }

    companion object {
        var DBManager: DBManager? = null
        // normalement pas de fuite, puisque 1 seul contexte
        fun getDBManager(context: Context): DBManager? {
            return if (this.DBManager == null) {
                DBManager(context)
            } else this.DBManager
        }
    }
}

